<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-da',
'0_langue' => 'dansk [da]',
'0_liste' => 'spip-da@rezo.net',
'0_mainteneur' => 'abc@dk2net.dk',

// A
'access_interface_graphique' => 'Back to the complete template interface', # NEW
'access_mode_texte' => 'Show the simplified text interface', # NEW
'admin_debug' => 'debug', # NEW
'admin_modifier_article' => 'Rediger artikel',
'admin_modifier_auteur' => 'Ret forfatter',
'admin_modifier_breve' => 'Rediger nyhed',
'admin_modifier_mot' => 'Ret n&oslash;gleord',
'admin_modifier_rubrique' => 'Rediger afsnit',
'admin_recalculer' => 'Opdater side',
'afficher_trad' => 'vis overs&aelig;ttelser',
'alerte_maj_impossible' => '<b>Advarsel!</b> Opdatering af SQL databasen til version @version@&#381;mislykkedes, m&aring;ske p&aring; grund af et problem med rettigheder i forhold til databasen. Kontakt venligst din webhotel.', # MODIF
'alerte_modif_info_concourante' => 'WARNING: This information has been modified elsewhere. The current value is&nbsp;:', # NEW
'analyse_xml' => 'XML parsing', # NEW
'annuler' => 'Annuler',
'antispam_champ_vide' => 'Please leave this field empty:', # NEW
'articles_recents' => 'De seneste artikler',
'avis_archive_incorrect' => 'arkivfilen er ikke en gyldig SPIP fil',
'avis_archive_invalide' => 'arkivfilen er ikke gyldig',
'avis_attention' => 'Advarsel!',
'avis_champ_incorrect_type_objet' => 'Ugyldigt feltnavn @name@ for et objekt af typen @type@',
'avis_colonne_inexistante' => 'Kolonnen @col@ findes ikke',
'avis_echec_syndication_01' => 'Syndikering mislykket: enten er den valgte datakilde utilg&aelig;ngelig eller ogs&aring; indeholder den ingen artikler.',
'avis_echec_syndication_02' => 'Syndication mislykket: kunne ikke f&aring; forbindelse til den valgte datakilde.',
'avis_erreur' => 'Fejl: se nedenfor\';',
'avis_erreur_connexion' => 'Ingen forbindelse',
'avis_erreur_cookie' => 'cookie-problem', # MODIF
'avis_erreur_fonction_contexte' => 'Programfejl. Denne funktion burde ikke kaldes i denne sammenh&aelig;ng.', # MODIF
'avis_erreur_mysql' => 'SQL fejl', # MODIF
'avis_erreur_sauvegarde' => 'Fejl i sikkerhedskopi (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Problem entering the private area', # NEW

// B
'barre_a_accent_grave' => 'Inds&aelig;t et stort A med accent grave',
'barre_aide' => 'Brug typografiske genveje til at forfine layoutet',
'barre_e_accent_aigu' => 'Inds&aelig;t et stort E med accent',
'barre_eo' => 'Inds&aelig;t oe ligatur',
'barre_eo_maj' => 'Inds&aelig;t stort OE ligatur',
'barre_euro' => 'Inds&aelig;t et &euro;-symbol',
'barre_gras' => 'Skriv med {{fed type}}',
'barre_guillemets' => 'S&aelig;t i "anf&oslash;rselstegn" ',
'barre_guillemets_simples' => 'S&aelig;t i \'anf&oslash;rselstegn\' ',
'barre_intertitre' => 'G&oslash;r til {{{underoverskrift}}}',
'barre_italic' => 'Skriv med {kursiv}',
'barre_lien' => 'Lav til et [hyperlink->http://...]',
'barre_lien_input' => 'Angiv m&aring;let for dit hyperlink (du kan angive en internetadresse p&aring; formen  http://www.websted.dk eller bare nummeret p&aring; en artikel p&aring; dette websted).',
'barre_note' => 'G&oslash;r til en [[Fodnote]]',
'barre_paragraphe' => 'Create a paragraph', # NEW
'barre_quote' => '<quote>Citer en besked</quote>',
'bouton_ajouter_document' => 'Tilf&oslash;j et dokument',
'bouton_ajouter_image' => 'TILF&Oslash;J BILLEDE', # MODIF
'bouton_ajouter_image_document' => 'Tilf&oslash;j et billede eller dokument',
'bouton_changer' => 'Opdater',
'bouton_chercher' => 'S&oslash;g',
'bouton_choisir' => 'V&aelig;lg',
'bouton_download' => 'Download',
'bouton_enregistrer' => 'Gem',
'bouton_radio_desactiver_messagerie_interne' => 'Sl&aring; intern meddelelsesfunktion fra',
'bouton_radio_envoi_annonces' => 'Send redaktionelle nyheder',
'bouton_radio_non_envoi_annonces' => 'Send ingen nyheder',
'bouton_radio_non_envoi_liste_nouveautes' => 'Send ikke oversigt over seneste nyheder',
'bouton_recharger_page' => 'genindl&aelig;s denne side',
'bouton_telecharger' => 'Hent',
'bouton_valider' => 'Godkend',

// C
'cal_apresmidi' => 'eftermiddag(p.m.)',
'cal_jour_entier' => 'hele dagen',
'cal_matin' => 'morgen (a.m.)',
'cal_par_jour' => 'daglig kalender',
'cal_par_mois' => 'm&aring;nedlig kalender',
'cal_par_semaine' => 'ugentlig kalender',
'choix_couleur_interface' => 'farve',
'choix_interface' => 'choice of interface', # NEW
'colonne' => 'Kolonne',
'confirm_changer_statut' => 'Bekr&aelig;ftelse n&oslash;dvendig: Du har bedt om at &aelig;ndre denne artikels status. Vil du forts&aelig;tte? ',
'correcte' => 'correct', # NEW

// D
'date_aujourdhui' => 'i dag',
'date_avant_jc' => 'f.v.t.',
'date_dans' => 'in @delai@', # NEW
'date_de_mois_1' => '@j@ @nommois@',
'date_de_mois_10' => '@j@ @nommois@',
'date_de_mois_11' => '@j@ @nommois@',
'date_de_mois_12' => '@j@ @nommois@',
'date_de_mois_2' => '@j@ @nommois@',
'date_de_mois_3' => '@j@ @nommois@',
'date_de_mois_4' => '@j@ @nommois@',
'date_de_mois_5' => '@j@ @nommois@',
'date_de_mois_6' => '@j@ @nommois@',
'date_de_mois_7' => '@j@ @nommois@',
'date_de_mois_8' => '@j@ @nommois@',
'date_de_mois_9' => '@j@ @nommois@',
'date_demain' => 'i morgen',
'date_fmt_heures_minutes' => '@h@:@m@',
'date_fmt_jour_heure' => '@jour@ kl. @heure@',
'date_fmt_jour_mois' => '@jourmois@',
'date_fmt_jour_mois_annee' => '@jourmois@&nbsp;@annee@',
'date_fmt_mois_annee' => '@nommois@ @annee@',
'date_fmt_nomjour_date' => '@nomjour@ den @date@',
'date_heures' => 'timer',
'date_hier' => 'i g&aring;r',
'date_il_y_a' => '@delai@ ago', # NEW
'date_jnum1' => '1',
'date_jnum10' => '10.',
'date_jnum11' => '11.',
'date_jnum12' => '12.',
'date_jnum13' => '13.',
'date_jnum14' => '14.',
'date_jnum15' => '15.',
'date_jnum16' => '16.',
'date_jnum17' => '17.',
'date_jnum18' => '18.',
'date_jnum19' => '19.',
'date_jnum2' => '2.',
'date_jnum20' => '20.',
'date_jnum21' => '21.',
'date_jnum22' => '22.',
'date_jnum23' => '23.',
'date_jnum24' => '24.',
'date_jnum25' => '25.',
'date_jnum26' => '26.',
'date_jnum27' => '27.',
'date_jnum28' => '28.',
'date_jnum29' => '29.',
'date_jnum3' => '3.',
'date_jnum30' => '30.',
'date_jnum31' => '31.',
'date_jnum4' => '4.',
'date_jnum5' => '5.',
'date_jnum6' => '6.',
'date_jnum7' => '7.',
'date_jnum8' => '8.',
'date_jnum9' => '9.',
'date_jour_1' => 's&oslash;ndag',
'date_jour_1_abbr' => 'S&oslash;n.',
'date_jour_1_initiale' => 'S.', # NEW
'date_jour_2' => 'mandag',
'date_jour_2_abbr' => 'Man.',
'date_jour_2_initiale' => 'M.', # NEW
'date_jour_3' => 'tirsdag',
'date_jour_3_abbr' => 'Tir.',
'date_jour_3_initiale' => 'T.',
'date_jour_4' => 'onsdag',
'date_jour_4_abbr' => 'Ons.',
'date_jour_4_initiale' => 'O.',
'date_jour_5' => 'torsdag',
'date_jour_5_abbr' => 'Tor.',
'date_jour_5_initiale' => 'T.',
'date_jour_6' => 'fredag',
'date_jour_6_abbr' => 'Fre.',
'date_jour_6_initiale' => 'F.',
'date_jour_7' => 'l&oslash;rdag',
'date_jour_7_abbr' => 'L&oslash;r.',
'date_jour_7_initiale' => 'L.',
'date_jours' => 'dage',
'date_minutes' => 'minutter',
'date_mois' => 'm&aring;neder',
'date_mois_1' => 'januar',
'date_mois_10' => 'oktober',
'date_mois_11' => 'november',
'date_mois_12' => 'december',
'date_mois_2' => 'februar',
'date_mois_3' => 'marts',
'date_mois_4' => 'april',
'date_mois_5' => 'maj',
'date_mois_6' => 'juni',
'date_mois_7' => 'juli',
'date_mois_8' => 'august',
'date_mois_9' => 'september',
'date_saison_1' => 'vinter',
'date_saison_2' => 'for&aring;r',
'date_saison_3' => 'sommer',
'date_saison_4' => 'efter&aring;r',
'date_secondes' => 'sekunder',
'date_semaines' => 'uger',
'date_un_mois' => 'm&aring;ned',
'date_une_heure' => 'time',
'date_une_minute' => 'minut',
'date_une_seconde' => 'sekund',
'date_une_semaine' => 'uge',
'dirs_commencer' => ' for at kunne begynde installationen',
'dirs_preliminaire' => 'Forberedelser: <b>Ops&aelig;tning af adgangsrettigheder</b>',
'dirs_probleme_droits' => 'Problem med adgangsrettigheder', # MODIF
'dirs_repertoires_absents' => '<b>F&oslash;lgende kataloger blev ikke fundet: <ul>@bad_dirs@.</ul> </b>
  <p>Det skyldes sandsynligvis forkert brug af store og sm&aring; bogstaver.
  Kontroller, at katalognavnene har samme store og sm&aring; bogstaver som vist ovenfor.
  Hvis ikke, sm&aring; brug et FTP-program til at omd&oslash;be dem, for at rette fejlen.
  <p>Derefter kan du', # MODIF
'dirs_repertoires_suivants' => '<b>F&oslash;lgende kataloger mangler skriveadgang: <ul>@bad_dirs@.</ul> </b>

  <p>For at &aelig;ndre dette skal du benytte din FTP-klient til at s&aelig;tte adgangsrettigheder
  for hvert katalog. Fremgangsm&aring;den er vist i brugerh&aring;ndbogen.

  <p>N&aring;r du har fuldf&oslash;rt dette, kan du ', # MODIF
'double_occurrence' => 'Double occurrence', # MODIF

// E
'en_cours' => 'processing', # NEW
'entree_dimensions' => 'St&oslash;rrelse:',
'entree_titre_document' => 'Dokumentoverskrift:',
'entree_titre_image' => 'Billedoverskrift:',
'envoi_via_le_site' => 'Sent via the site', # NEW
'erreur' => 'Fejl',
'erreur_balise_non_fermee' => 'last tag not closed:', # NEW
'erreur_texte' => 'fejl',
'etape' => 'Stage', # NEW

// F
'fichier_introuvable' => 'File not found: @fichier@', # NEW
'form_auteur_confirmation' => 'Bekr&aelig;ft venligst din e-post adresse',
'form_auteur_email_modifie' => 'Din e-post adresse er blevet &aelig;ndret',
'form_auteur_envoi_mail_confirmation' => 'A confirmation email has been sent to @email@. You need to visit the URL mentioned in this message in order to validate your email address.', # NEW
'form_auteur_mail_confirmation' => '<NEW>Hej,

Du har bedt om at &aelig;ndre din e-post adresse.
For at bekr&aelig;fte din ny adresse, m&aring; du forbinde dig til
adressen nedenfor. (Ellers ignoreres din foresp&oslash;rgsel.):

    @url@
',
'form_deja_inscrit' => 'Du har allerede tilmeldt dig.',
'form_email_non_valide' => 'Din e-mail-adresse er ikke gyldig.',
'form_forum_access_refuse' => 'Du har ikke mere adgang til dette websted.',
'form_forum_bonjour' => 'Goddag,', # MODIF
'form_forum_email_deja_enregistre' => 'Denne e-mail-adresse er allerede tilmeldt. Du kan derfor benytte din s&aelig;dvanlige adgangskode.',
'form_forum_identifiant_mail' => 'Dine nye adgangsoplysninger er netop sendt til dig via e-mail.',
'form_forum_identifiants' => 'Personlige adgangsoplysninger',
'form_forum_indiquer_nom_email' => 'V&aelig;r venlig at indtaste dit navn og din e-mail-adresse her. Du vil kort tid efter modtage dine personlige adgangsoplysninger via e-mail.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(dette er en automatisk udkrevet meddelelse)',
'form_forum_pass' => 'adgangskode:',
'form_forum_probleme_mail' => 'E-mail-problem: adgangsoplysninger kunne ikke sendes.',
'form_forum_voici1' => 'Her er dine adgangsoplysninger for at kunne deltage i forummer p&aring; webstedet "@nom_site_spip@" (@adresse_site@):', # MODIF
'form_forum_voici2' => 'Her er dine adgangsoplysninger for at kunne indsende artikler til webstedet "@nom_site_spip@" (@adresse_login@):', # MODIF
'form_indiquer_email' => 'Indtast venligst din e-mail-adresse.',
'form_indiquer_nom' => 'Indtast venligst dit navn.',
'form_indiquer_nom_site' => 'Indtast venligst dit websteds navn.',
'form_pet_adresse_site' => 'Dit websteds URL',
'form_pet_aucune_signature' => 'Ingen signatur svarer til denne kode...',
'form_pet_confirmation' => 'Bekr&aelig;ft venligst din signatur:',
'form_pet_deja_enregistre' => 'Webstedet er allerede registreret',
'form_pet_deja_signe' => 'Du har allerede signeret denne tekst.',
'form_pet_envoi_mail_confirmation' => 'En e-mail er netop sendt til dig som bekr&aelig;ftelse. Du b&oslash;r g&aring; ind p&aring; den URL, som er angivet i denne mail, for at bekr&aelig;fte din signatur.', # MODIF
'form_pet_mail_confirmation' => 'Goddag,

Du har &oslash;nsket at st&oslash;tte denne appel:
@titre@.

Du at afgivet f&oslash;lgende oplysninger:
    Navn: @nom_email@
    Websted: @nom_site@ - @url_site@

VIGTIGT...
For at bekr&aelig;fte din underskrift skal du blot klikke dig ind p&aring;
adressen nedenfor (ellers vil underskriften blive afvist):
    @url@

Tak for din deltagelse
', # MODIF
'form_pet_message_commentaire' => 'Meddelelse eller kommentar?',
'form_pet_nom_site2' => 'Navn p&aring; dit websted',
'form_pet_probleme_liens' => 'Please edit your message, taking out all hyperlinks.', # NEW
'form_pet_probleme_technique' => 'Teknisk problem: Appelfunktionen er i &oslash;jeblikket ude af drift.',
'form_pet_signature_pasprise' => 'Din underskrift er ikke godkendt.',
'form_pet_signature_validee' => 'Din underskrift er godkendt. Den vil blive offentliggjort, n&aring;r webstedet opdateres. Tak!',
'form_pet_site_deja_enregistre' => 'Dette websted er allerede registreret',
'form_pet_url_invalide' => 'Den URL, du har angivet, er ikke gyldig.',
'form_pet_votre_email' => 'Din e-mail-adresse',
'form_pet_votre_nom' => 'Dit navn eller alias',
'form_pet_votre_site' => 'Hvis du har et websted, kan du angive den nedenfor',
'form_prop_confirmer_envoi' => 'Bekr&aelig;ft afsendelse',
'form_prop_description' => 'Beskrivelse/kommentar',
'form_prop_enregistre' => 'Din forslag er modtaget, det vil blive offentliggjort, n&aring;r det er godkendt af webstedets administratorer.',
'form_prop_envoyer' => 'Send en meddelelse',
'form_prop_indiquer_email' => 'Indtast en gyldig e-mail-adresse',
'form_prop_indiquer_nom_site' => 'Indtast webstedets navn.',
'form_prop_indiquer_sujet' => 'Angiv et emne',
'form_prop_message_envoye' => 'Meddelelse sendt',
'form_prop_nom_site' => 'Webstedets navn',
'form_prop_non_enregistre' => 'Din forslag er ikke modtaget.',
'form_prop_sujet' => 'Emne',
'form_prop_url_site' => 'Webstedets URL',
'forum_acces_refuse' => 'Du har ikke mere adgang til disse forummer',
'forum_attention_dix_caracteres' => '<b>Advarsel!</b> dit indl&aelig;g er mindre end ti tegn langt.', # MODIF
'forum_attention_trois_caracteres' => '<b>Advarsel!</b> dit emne er mindre end tre tegn langt.', # MODIF
'forum_attention_trop_caracteres' => '<b>Warning&nbsp;!</b> your message is too long (@compte@ characters)&nbsp;: to be able to save it, the message should not contain more than @max@ characters.', # NEW
'forum_avez_selectionne' => 'Du har valgt:',
'forum_cliquer_retour' => 'Klik  <a href=\'@retour_forum@\'>her</a> for at forts&aelig;tte.',
'forum_forum' => 'forum',
'forum_info_modere' => 'Dette forum benytter forh&aring;ndsgodkendelse: dit bidrag vil f&oslash;rst blive offentliggjort, n&aring;r det er godkendt af en administrator.',
'forum_lien_hyper' => '<b>Hypertekst link</b> (valgfrit)',
'forum_message_definitif' => 'Endeligt indl&aelig;g: send til webstedet',
'forum_message_trop_long' => 'Dit indl&aelig;g er for langt. Maksimal l&aelig;ngde er 20.000 tegn.',
'forum_ne_repondez_pas' => 'Undlad at besvare denne e-mail, men g&aring; i stedet til forummet p&aring; denne adresse:',
'forum_non_inscrit' => 'Enten er du ikke tilmeldt, eller adresse eller adgangskode er forkert.',
'forum_page_url' => '(Hvis dit indl&aelig;g henviser til en artikel, der er offentliggjort p&aring; Internettet, eller til en side der indeholder yderligere oplysninger, s&aring; angiv venligst sidens titel og dens adresse eller URL nedenfor).',
'forum_par_auteur' => 'af @auteur@',
'forum_poste_par' => 'Indl&aelig;g @parauteur@ som svar p&aring; din artikel.', # MODIF
'forum_probleme_database' => 'Databaseproblem, dit indl&aelig;g er ikke modtaget.',
'forum_qui_etes_vous' => '<b>Hvem er du?</b> (valgfrit)',
'forum_texte' => 'Indl&aelig;ggets tekst:',
'forum_titre' => 'Titel:',
'forum_titre_erreur' => 'Fejl...',
'forum_url' => 'URL:',
'forum_valider' => 'Kontroller gyldighed',
'forum_voir_avant' => 'Vis indl&aelig;g f&oslash;r indsendelse',
'forum_votre_email' => 'Din e-mail-adresse:',
'forum_votre_nom' => 'Dit navn (eller alias):',
'forum_vous_enregistrer' => 'F&oslash;r du kan deltage i dette forum,
		skal du tilmelde dig. Indtast venligst nedenfor de
		personlige adgangsoplysninger, du har f&aring;et tilsendt.
		Hvis du ikke allerede har tilmeldt dig, skal du g&oslash;re det.',
'forum_vous_inscrire' => 'tilmeld dig </a> f&oslash;rst.', # MODIF

// I
'ical_texte_rss_articles' => 'Filen "backend" for artiklerne p&aring; dette websted findes p&aring; f&oslash;lgende adresse: ',
'ical_texte_rss_articles2' => 'Du kan ligeledes finde frem til datakilder for artiklerne, der befinder sig i hver af  wedstedets afsnit.  ',
'ical_texte_rss_breves' => 'Der eksisterer envidere en fil, som indeholder webstedets nyheder. Ved at pr&aelig;cisere et afsnits nummer f&aring;r du udelukkende nyhederne fra dette afsnit. ',
'icone_a_suivre' => 'Opgaver',
'icone_admin_site' => 'Ops&aelig;tning',
'icone_agenda' => 'Dagbog',
'icone_aide_ligne' => 'Online hj&aelig;lp',
'icone_articles' => 'Artikler',
'icone_auteurs' => 'Forfattere',
'icone_breves' => 'Nyheder',
'icone_brouteur' => 'Hurtig browsing',
'icone_configuration_site' => 'Konfiguration',
'icone_configurer_site' => 'Konfigurer dit websted',
'icone_creer_nouvel_auteur' => 'Opret ny forfatter',
'icone_creer_rubrique' => 'Opret afsnit',
'icone_creer_sous_rubrique' => 'Opret underafsnit',
'icone_deconnecter' => 'Log ud',
'icone_discussions' => 'Diskussioner',
'icone_doc_rubrique' => 'Dokumenter i afsnit',
'icone_ecrire_article' => 'Skriv ny artikel',
'icone_edition_site' => 'Rediger websted',
'icone_forum_administrateur' => 'Administratorforum',
'icone_forum_suivi' => 'Forumopf&oslash;lgning',
'icone_gestion_langues' => 'Sprogadministration',
'icone_informations_personnelles' => 'Personlig information',
'icone_interface_complet' => 'Komplet brugergr&aelig;nseflade',
'icone_interface_simple' => 'Forenklet brugergr&aelig;nseflade',
'icone_maintenance_site' => 'Vedligeholdelse',
'icone_messagerie_personnelle' => 'Personlige meddelelser',
'icone_mots_cles' => 'N&oslash;gleord',
'icone_nouvelle_breve' => 'Skriv ny nyhed',
'icone_repartition_actuelle' => 'Vis faktisk fordeling',
'icone_repartition_debut' => 'Vis fordeling siden start',
'icone_repartition_visites' => 'Bes&oslash;gsfordeling',
'icone_rubriques' => 'Afsnit',
'icone_sauver_site' => 'Websted backup',
'icone_site_entier' => 'Hele webstedet',
'icone_sites_references' => 'Links',
'icone_statistiques' => 'Webstedsstatistik',
'icone_statistiques_visites' => 'Bes&oslash;gsstatistik',
'icone_suivi_activite' => 'Opf&oslash;lgning p&aring; webstedets aktiviteter',
'icone_suivi_actualite' => 'Webstedets udvikling',
'icone_suivi_forums' => 'Administrer forummer',
'icone_suivi_pettions' => 'Administrer appeller',
'icone_suivi_revisions' => '<NEW>Artikel&aelig;ndringer',
'icone_supprimer_document' => 'Slet dette dokument',
'icone_supprimer_image' => 'Slet dette billede',
'icone_supprimer_message' => 'Slet denne meddelelse',
'icone_tous_articles' => 'Alle dine artikler',
'icone_tous_auteur' => 'Alle forfattere',
'icone_valider_message' => 'Godkend meddelelse',
'icone_visiter_site' => 'Bes&oslash;g websted',
'icone_voir_en_ligne' => 'Vis online',
'image_tourner_180' => '<NEW>Drej 180&deg;',
'image_tourner_droite' => '<NEW>Drej 90&deg; til h&oslash;jre',
'image_tourner_gauche' => '<NEW>Drej 90&deg; til venstre',
'img_indisponible' => 'image unavailable', # NEW
'impossible' => 'umuligt',
'info_a_suivre' => 'OPGAVER&raquo;',
'info_a_valider' => '[at kontrollere]',
'info_acces_interdit' => 'Adgang forbudt',
'info_acces_refuse' => 'Ingen adgang',
'info_action' => 'Handling: @action@',
'info_administrer_rubriques' => 'Du kan administrere dette afsnit og dets underafsnit',
'info_adresse_non_indiquee' => 'Du har ikke angivet en adresse at teste!',
'info_aide' => 'HJ&AElig;LP:',
'info_ajouter_mot' => 'Tilf&oslash;j n&oslash;gleord',
'info_annonce' => 'ANNONCERING',
'info_annonces_generales' => 'Generelle annonceringer:',
'info_article_propose' => 'Artikel indsendt',
'info_article_publie' => 'Artikel offentliggjort',
'info_article_redaction' => 'Artikel p&aring; vej',
'info_article_refuse' => 'Artikel afvist',
'info_article_supprime' => 'Artikel slettet',
'info_articles' => 'Artikler',
'info_articles_a_valider' => 'Artikler til godkendelse',
'info_articles_nb' => '@nb@ articles', # NEW
'info_articles_proposes' => 'Indsendte artikler',
'info_articles_un' => '1 article', # NEW
'info_auteurs_nombre' => 'forfatter(e):',
'info_authentification_ftp' => 'Adgangskontrol (ved FTP).',
'info_bloquer_lien' => 'bloker dette link',
'info_breves_02' => 'Nyheder',
'info_breves_2' => 'nyheder',
'info_breves_nb' => '@nb@ news items', # NEW
'info_breves_un' => '1 news item', # NEW
'info_breves_valider' => 'Nyheder der afventer godkendelse',
'info_connexion_refusee' => 'Opkobling afvist',
'info_contact_developpeur' => 'Kontakt en udvikler.',
'info_contenance' => 'Dette websted indeholder:',
'info_contribution' => 'indl&aelig;g i fora',
'info_copyright' => '@spip@ er fri software der distribueres @lien_gpl@.',
'info_copyright_doc' => 'For yderligere oplysninger bes&oslash;g webstedet <a href="@spipnet@">http://www.spip.net/da</a>.', # MODIF
'info_copyright_gpl' => 'under GPL licens',
'info_cours_edition' => 'Artikler undervejs',
'info_creer_repertoire' => 'Opret en fil eller et katalog med navnet:',
'info_creer_repertoire_2' => 'i underkataloget <b>@repertoire@</b>, og derefter', # MODIF
'info_creer_vignette' => 'automated creation of the thumbnail', # NEW
'info_deplier' => 'Luk op',
'info_descriptif_nombre' => 'beskrivelse(r):',
'info_description' => 'Beskrivelse:',
'info_description_2' => 'Beskrivelse:',
'info_dimension' => 'St&oslash;rrelse:',
'info_document' => 'Dokument',
'info_document_indisponible' => 'This document is unavailable', # NEW
'info_documents' => 'Documents', # NEW
'info_documents_nb' => '@nb@ documents', # NEW
'info_documents_un' => '1 document', # NEW
'info_echange_message' => 'SPIP tillader udveksling af meddelelser og oprettelse af private diskussionsforummer mellem deltagere p&aring; webstedet. Du kan til- eller frav&aelig;lge denne funktion.',
'info_ecire_message_prive' => 'Skriv en privat meddelelse',
'info_email_invalide' => 'Ugyldig e-mail-adresse.',
'info_en_cours_validation' => 'Dine artikler undervejs',
'info_en_ligne' => 'Online nu:',
'info_envoyer_message_prive' => 'Send en privat meddelelse til forfatteren',
'info_erreur_requete' => 'Fejl i foresp&oslash;rgsel:',
'info_erreur_squelette2' => 'Ingen template parat <b>@fichier@</b>...',
'info_erreur_systeme' => 'System fejl (errno @errsys@)',
'info_erreur_systeme2' => 'Harddisken er m&aring;ske fyldt eller databasen er skadet. <br />
 <font color=\'red\'>pr&oslash;v <a href=\'@script@\'>at reparere databasen</a>,
eller kontakt din internetudbyder.</font>', # MODIF
'info_fini' => 'Det er overst&aring;et!',
'info_format_image' => 'Billedformater til brug ved dannelse af piktogrammer: @gd_formats@.',
'info_format_non_defini' => 'ukendt format',
'info_grand_ecran' => 'Stort sk&aelig;rmbillede',
'info_image_aide' => 'HJ&AElig;LP',
'info_image_process_titre' => 'How to create thumbnails', # NEW
'info_impossible_lire_page' => '<b>Fejl!</b> Siden kan ikke l&aelig;ses <tt><html>@test_proxy@</html></tt> gennem proxy&yen;en <tt>', # MODIF
'info_inclusion_directe' => 'Direkte indlejring:',
'info_inclusion_vignette' => 'Medtag piktogram:',
'info_installation_systeme_publication' => 'Installation af publiceringssystemet ...',
'info_installer_documents' => 'Du kan automatisk installere alle dokumenter, som findes i kataloget @upload@.', # MODIF
'info_installer_ftp' => 'Som administrator kan du via FTP indl&aelig;se filer i kataloget @upload@, s&aring; du senere kan hente dem der.', # MODIF
'info_installer_images' => 'Du kan indl&aelig;se filer i formaterne JPEG, GIF og PNG.',
'info_installer_images_dossier' => 'Indl&aelig;s billeder i kataloget @upload@ for at kunne hente dem her.', # MODIF
'info_installer_tous_documents' => 'Indl&aelig;s alle dokumenter',
'info_interface_complete' => 'Fuld brugergr&aelig;nseflade',
'info_interface_simple' => 'Forenklet brugergr&aelig;nseflade',
'info_joindre_document_article' => 'Du kan vedh&aelig;fte din artikel dokumenter af typerne',
'info_joindre_document_rubrique' => 'Du kan til dette afsnit tilf&oslash;je dokumenter af typerne',
'info_joindre_documents_article' => 'Du kan vedh&aelig;fte din artikel dokumenter af typerne:',
'info_l_article' => 'artiklen',
'info_la_breve' => 'nyheden',
'info_la_rubrique' => 'afsnittet',
'info_langue_principale' => 'Webstedets hovedsprog',
'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixels',
'info_les_auteurs_1' => 'af @les_auteurs@',
'info_logo_format_interdit' => 'Only logos in the formats @formats@ are allowed.', # NEW
'info_logo_max_poids' => 'Logos must be less than @maxi@ (this file is @actuel@).', # NEW
'info_logo_max_taille' => 'Logos must be less than @maxi@ (this file is @actuel@).', # NEW
'info_mail_fournisseur' => 'ditnavn@udbyder.dk',
'info_message_2' => 'BESKED',
'info_message_supprime' => 'BESLED SLETTET',
'info_messages_nb' => '@nb@ messages', # NEW
'info_messages_un' => '1 message', # NEW
'info_mise_en_ligne' => 'Dato for offentligg&oslash;relse online:',
'info_modification_parametres_securite' => '&aelig;ndring af sikkerhedsops&aelig;tning',
'info_mois_courant' => 'I l&oslash;bet af m&aring;neden:',
'info_mot_cle_ajoute' => 'F&oslash;lgende n&oslash;gleord er tilf&oslash;jet til',
'info_multi_herit' => 'Standardsprog',
'info_multi_langues_soulignees' => 'De <u>inderstregede sprog</u> rummer overs&aelig;ttelse af alle tekster i brugergr&aelig;nsefladen. Hvis du v&aelig;lger disse sprog, vil mange elementer p&aring; det offentlige websted (datoer, forularer) automatisk blive oversat. Hvad ang&aring;r de ikke-understregede sprog, vil disse elementer fremtr&aelig;de p&aring; webstedets hovedsprog.', # MODIF
'info_multilinguisme' => 'Flersprogethed',
'info_nom_non_utilisateurs_connectes' => 'Dit navn findes ikke p&aring; listen over tilsluttede brugere.',
'info_nom_utilisateurs_connectes' => 'Dit navn figurerer p&aring; listen over online brugere.',
'info_nombre_en_ligne' => 'Online nu:',
'info_non_resultat' => 'Ingen resultater ved s&oslash;gning efter "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'Du anvender ikke webstedets interne meddelelsessystem.',
'info_nouveau_message' => 'DU HAR EN NY MEDDELELSE',
'info_nouveaux_messages' => 'DU HAR @total_messages@ NYE MEDDELELSER',
'info_numero_abbreviation' => 'No', # NEW
'info_obligatoire' => 'This information is required', # NEW
'info_panne_site_syndique' => 'Syndikeret side er ude af trit',
'info_pense_bete' => 'HUSKESEDDEL',
'info_petit_ecran' => 'Lille sk&aelig;rmbillede',
'info_petition_close' => 'Petition closed', # NEW
'info_pixels' => 'pixels',
'info_plusieurs_mots_trouves' => 'Der blev fundet flere n&oslash;gleord ved s&oslash;gning efter "@cherche_mot@":',
'info_popularite_5' => 'polularitet:',
'info_portfolio' => 'Portfolio', # NEW
'info_portfolio_automatique' => 'Automatisk album:',
'info_premier_resultat' => '[@debut_limit@ f&oslash;rste resultater af @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ f&oslash;rste resultater af @total@]',
'info_probleme_grave' => 'problem med',
'info_propose_1' => '[@nom_site_spip@] Indl&aelig;g: @titre@',
'info_propose_2' => 'Artikel indsendt
-----------------',
'info_propose_3' => 'Artiklen "@titre@" er sendt til offentligg&oslash;relse.',
'info_propose_4' => 'Du inviteres til at anmelde den over for de &oslash;vrige forfattere',
'info_propose_5' => 'i det forum den tilh&oslash;rer. Den findes p&aring; adressen:',
'info_publie_01' => 'Artiklen "@titre@" er vurderet af @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] OFFENTLIGG&Oslash;R: @titre@',
'info_publie_2' => 'Artikel offentliggjort
-----------------',
'info_rechercher' => 'S&oslash;gning',
'info_rechercher_02' => 'S&oslash;gning:',
'info_remplacer_vignette' => 'Erstatte standardpiktogrammet med et eget ikon:',
'info_retablir_lien' => 'Genopret dette link',
'info_retirer_mot' => 'Slet dette n&oslash;gleord',
'info_retirer_mots' => 'Slet alle n&oslash;gleord',
'info_rubriques_nb' => '@nb@ sections', # NEW
'info_rubriques_un' => '1 section', # NEW
'info_sans_titre_2' => 'uden overskrift',
'info_selectionner_fichier' => 'Du kan v&aelig;lge en fil fra mappen @upload@', # MODIF
'info_selectionner_fichier_2' => 'V&aelig;lg en fil:',
'info_signature_supprimee' => 'Signature deleted', # NEW
'info_signature_supprimee_erreur' => 'Error: this deletion code does not correspond to any signature', # NEW
'info_site_attente' => 'Websted afventer godkendelse',
'info_site_reference' => 'Online henvisning',
'info_site_refuse' => 'Websted afvist',
'info_sites_nb' => '@nb@ sites', # NEW
'info_sites_referencer' => 'Link til websted',
'info_sites_un' => '1 site', # NEW
'info_supprimer_vignette' => 'slet piktogram',
'info_symbole_bleu' => '<b>Bl&aring;t</b> symbol henviser til et <b>memo</b>: dvs. en meddelelse til privat brug.', # MODIF
'info_symbole_jaune' => '<b>Gult</b> symbol henviser til en <b>annoncering til alle redakt&oslash;rer</b>: den kan redigeres af alle redakt&oslash;rer og er synlig for alle redakt&oslash;rer.', # MODIF
'info_symbole_vert' => '<b>Gr&oslash;nt</b> symbol henviser til <b>meddelelser udvekslet med andre brugere</b> p&aring; webstedet.', # MODIF
'info_syndication' => 'syndikering:',
'info_syndication_articles' => 'bidrag',
'info_telecharger' => 'Hent fra din computer:',
'info_telecharger_nouveau_logo' => 'Hent nyt logo:',
'info_telecharger_ordinateur' => 'Hent fra din computer:',
'info_tous_resultats_enregistres' => '[alle resultater er registreret]',
'info_tout_afficher' => 'Vis alle',
'info_travaux_texte' => 'Dette websted er endnu ikke f&aelig;rdigkonfigureret. Kom tilbage senere...',
'info_travaux_titre' => 'Webstedet er under konstruktion',
'info_trop_resultat' => 'For mange resultater til "@cherche_mot@"; v&aelig;r venlig af afgr&aelig;nse s&oslash;gningen yderligere.',
'info_utilisation_messagerie_interne' => 'Du benytter webstedets interne meddelelsessystem.',
'info_valider_lien' => 'kontroller dette link',
'info_verifier_image' => ', kontroller venligst at alle billeder er overf&oslash;rt korrekt.',
'info_vignette_defaut' => 'Standardpiktogram',
'info_vignette_personnalisee' => 'Tilpasset piktogram',
'info_visite' => 'bes&oslash;g:',
'info_visites' => 'bes&oslash;g:',
'info_vos_rendez_vous' => 'Dine fremtidige aftaler',
'info_zoom' => 'zoom', # NEW
'infos_vos_pense_bete' => 'Dine memoer', # MODIF
'item_breve_proposee' => 'Nyhed indsendt',

// L
'lien_afficher_icones_seuls' => 'Vis kun piktogrammer',
'lien_afficher_texte_icones' => 'Vis piktogrammer og tekst',
'lien_afficher_texte_seul' => 'Vis kun tekst',
'lien_liberer' => 'frigiv',
'lien_liberer_tous' => 'frigiv disse artikler',
'lien_nouvea_pense_bete' => 'NYT MEMO',
'lien_nouveau_message' => 'NY MEDDELELSE',
'lien_nouvelle_annonce' => 'NY ANNONCERING',
'lien_petitions' => 'APPELLER',
'lien_popularite' => 'popularitet: @popularite@%',
'lien_racine_site' => 'TOP',
'lien_reessayer' => 'fors&oslash;g igen',
'lien_repondre_message' => 'Kommenter denne meddelelse',
'lien_supprimer' => 'slet',
'lien_tout_afficher' => 'Vis alle',
'lien_visite_site' => 'bes&oslash;g dette websted',
'lien_visites' => '@visites@ bes&oslash;gende',
'lien_voir_auteur' => 'Oplysninger om forfatter',
'ligne' => 'Line', # NEW
'login' => 'Connection', # NEW
'login_acces_prive' => 'adgang til det private omr&aring;de',
'login_autre_identifiant' => 'login med en anden brugeridentifikation',
'login_cookie_accepte' => 'Indstil din browser til at acceptere cookier (i hvert fald fra dette websted).',
'login_cookie_oblige' => 'For at identificere dig selv sikkert, skal din browser acceptere cookier.',
'login_deconnexion_ok' => 'Forbindelse afbrudt.',
'login_erreur_pass' => 'Forkert adgangskode.',
'login_espace_prive' => 'privat omr&aring;de',
'login_identifiant_inconnu' => 'Brugeridentifikationen "@login@" kendes ikke.',
'login_login' => 'Login:',
'login_login2' => 'Login (brugeridentifikation til dette websted):',
'login_login_pass_incorrect' => '(Forkert adgangskode eller ).',
'login_motpasseoublie' => 'glemt adgangskode?',
'login_non_securise' => 'Advarsel, denne formular er ikke sikret.

   Hvis du ikke vil risikere at din adgangskode bliver opsnappet p&aring; nettet, skal du aktivere

   Javascript i din browser og',
'login_nouvelle_tentative' => 'Nyt fors&oslash;g',
'login_par_ici' => 'Du er tilmeldt... p&aring; denne m&aring;de...',
'login_pass2' => 'Adgangskode:',
'login_preferez_refuser' => '<b>Hvis du foretr&aelig;kker at afvise cookies</b>, kan du anvende en anden opkoblingsm&aring;de (mindre sikker):',
'login_recharger' => 'genindl&aelig;s denne side',
'login_rester_identifie' => 'V&aelig;r kendt nogle dage',
'login_retour_public' => 'Tilbage til det offentlige websted',
'login_retour_site' => 'Tilbage til den offentlige websted',
'login_retoursitepublic' => 'tilbage til den offentlige websted',
'login_sans_cookiie' => 'Identifikation uden cookie',
'login_securise' => 'Secured login', # NEW
'login_sinscrire' => 'tilmelding',
'login_test_navigateur' => 'test af browser/nyt login',
'login_verifiez_navigateur' => '(Men kontroller, at din browser ikke har gemt adgangskoden...)',

// M
'masquer_colonne' => 'Hide this column', # NEW
'masquer_trad' => 'hide translations', # NEW
'module_fichiers_langues' => 'Sprogfiler',

// N
'navigateur_pas_redirige' => 'Hvis din browser ikke er viderestilt, klik her for at forts&aelig;tte. ',
'numero' => 'Number', # NEW

// O
'occurence' => 'Instance', # NEW
'onglet_affacer_base' => 'Slet databasen',
'onglet_auteur' => 'Forfatteren',
'onglet_contenu_site' => 'Webstedets indhold',
'onglet_evolution_visite_mod' => 'Tendens',
'onglet_fonctions_avances' => 'Avancerede funktioner',
'onglet_informations_personnelles' => 'Personlige oplysninger',
'onglet_interactivite' => 'Interaktivitet',
'onglet_messagerie' => 'Meddelelsesfunktion',
'onglet_messages_internes' => 'Interne meddelelser',
'onglet_messages_publics' => 'Offentlige meddelelser',
'onglet_messages_vide' => 'Meddelelser uden tekst',
'onglet_origine_visites' => 'Bes&oslash;gendes oprindelse',
'onglet_repartition_debut' => 'fra begyndelsen',
'onglet_repartition_lang' => 'efter sprog',
'onglet_repartition_rubrique' => 'Fordeling p&aring; afsnit',
'onglet_save_restaur_base' => 'Sikkerhedskopi/genindl&aelig;sning af databasen',
'onglet_vider_cache' => 'T&oslash;m cachen',
'ortho_trop_de_fautes2' => 'Start by correcting the most obvious mistakes, then try again.', # NEW

// P
'pass_choix_pass' => 'V&aelig;lg ny adgangskode:',
'pass_erreur' => 'Fejl',
'pass_erreur_acces_refuse' => '<b>Fejl:</b> du har ikke mere adgang til dette websted.',
'pass_erreur_code_inconnu' => '<b>Fejl:</b> denne kode har ikke adgang til dette websted.',
'pass_erreur_non_enregistre' => '<b>Fejl:</b> adressen <tt>@email_oubli@</tt> er ikke tilmeldt dette websted.',
'pass_erreur_non_valide' => '<b>Fejl:</b> e-mail-adressen <tt>@email_oubli@</tt> er ugyldig!',
'pass_erreur_probleme_technique' => '<b>Fejl:</b> denne e-mail kunne ikke sendes af tekniske grunde.',
'pass_espace_prive_bla' => 'Den private del af dette websted er &aring;ben for bes&oslash;gende efter tilmelding.
	N&aring;r du har tilmeldt dig, kan du gennemse artikler der er p&aring; vej, indsende artikler og deltage i alle fora.',
'pass_forum_bla' => 'Du har bedt om adgang til et forum, der er forbeholdt registrerede brugere.',
'pass_indiquez_cidessous' => 'Indtast nedenfor den e-mail-adresse, du tidligere har registreret. Du vil modtage en e-mail, der forklarer, hvordan du f&aring;r adgang.',
'pass_mail_passcookie' => '(dette er en automatisk dannet e-mail)

For at f&aring; adgang til webstedet 
@nom_site_spip@ (@adresse_site@)

skal du g&aring; til f&oslash;lgende adresse:
    @sendcookie@

Du kan s&aring; indtaste en ny adgangskode
og igen f&aring; adgang til webstedet.', # MODIF
'pass_mot_oublie' => 'Glemt adgangskode',
'pass_nouveau_enregistre' => 'Din nye adgangskode er registreret.',
'pass_nouveau_pass' => 'Ny adgangskode',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Glemt adgangskode',
'pass_quitter_fenetre' => 'Luk vinduet',
'pass_rappel_login' => 'P&aring;mindelse: din brugeridentifikation (login) er "@login@".',
'pass_recevoir_mail' => 'Du vil modtage en e-mail, der forklarer hvordan du kan f&aring; adgang til webstedet.',
'pass_retour_public' => 'Tilbage til det offentlige websted',
'pass_rien_a_faire_ici' => 'Intet at g&oslash;re her.',
'pass_vousinscrire' => 'Tilmelding til webstedet',
'precedent' => 'previous', # NEW
'previsualisation' => 'Preview', # NEW
'previsualiser' => 'Show preview', # NEW

// R
'retour' => 'Return', # NEW

// S
'spip_conforme_dtd' => 'SPIP finds this page to be in compliance with its DOCTYPE:', # NEW
'squelette' => 'template', # NEW
'squelette_inclus_ligne' => 'included template, line', # NEW
'squelette_ligne' => 'template, line', # NEW
'stats_visites_et_popularite' => '@visites@ bes&oslash;g; popularitet: @popularite@',
'suivant' => 'next', # NEW

// T
'taille_ko' => '@taille@&nbsp;kb',
'taille_mo' => '@taille@&nbsp;Mb',
'taille_octets' => '@taille@ byte',
'texte_actualite_site_1' => 'Denne side viser webstedets status og giver dig mulighed for at f&oslash;lge dine bidrag. Her kan du b&aring;de finde dine uafsluttede artikler og de artikler og nyheder, som du inviteres til at tilkendegive din mening om, samt en p&aring;mindelse om dine tidligere bidrag.<p><hr><p>N&aring;r du er blevet fortrolig med brugergr&aelig;nsefladen s&aring; klik p&aring; &laquo;',
'texte_actualite_site_2' => 'fuld brugergr&aelig;nseflade',
'texte_actualite_site_3' => '&raquo; for at f&aring; flere funktioner til r&aring;dighed.',
'texte_creation_automatique_vignette' => 'Dette websted tillader automatisk dannelse af miniaturepiktogrammer. Hvis du via denne formular indl&aelig;ser billeder i formatet @gd_formats@, vil de blive knyttet sammen med miniaturepiktogrammer med en maksimal st&oslash;rrelse p&aring; @taille_preview@ pixels.',
'texte_documents_associes' => 'F&oslash;lgende dokumenter er knyttet til artiklen  men inds&aelig;ttes ikke direkte. Afh&aelig;ngig af det offentlige websteds layout kan de optr&aelig;de som vedh&aelig;ftede dokumenter.',
'texte_erreur_mise_niveau_base' => 'Databasefejl under opgradering.
			Billedet <b>@fichier@</b> kunne ikke overf&oslash;res (artiklen @id_article@).<p>
			Noter omhyggeligt denne henvisning, gentag opgraderingsproceduren,
			og kontrolller sluttelig, at billederne stadig figurerer i dokumentet.', # MODIF
'texte_erreur_visiteur' => 'You have tried to enter the private area using a login which does not permit this.', # NEW
'texte_inc_auth_1' => 'Du har identificeret dig selv med login <b>@auth_login@</b>, men det findes ikke (mere) i databasen. 
		Pr&oslash;v at ', # MODIF
'texte_inc_auth_2' => 'genetablere forbindelsen',
'texte_inc_auth_3' => 'efter om n&oslash;dvendigt at have lukket din browser ned og genstartet den igen.',
'texte_inc_config' => '&AElig;ndringer nedenfor vil markant p&aring;virke webstedets funktion. 
	 Du r&aring;des til ikke at &aelig;ndre dem, med mindre du er fortrolig med SPIP-systemets funktion.
	<br /><br /><b>I almindelighed r&aring;des du kraftigt til at lade den hovedansvarlige webmaster p&aring; dit websted tage sig af denne side.</b>', # MODIF
'texte_inc_meta_1' => 'Kontroller venligst som administrator', # MODIF
'texte_inc_meta_2' => 'skriveadgangen',
'texte_inc_meta_3' => 'til kataloget ecrire/', # MODIF
'texte_statut_en_cours_redaction' => 'under redigering',
'texte_statut_poubelle' => 'i papirkurven',
'texte_statut_propose_evaluation' => 'indsendt til godkendelse',
'texte_statut_publie' => 'offentliggjort online',
'texte_statut_refuse' => 'afvist',
'titre_ajouter_mot_cle' => 'TILF&Oslash;J N&Oslash;GLEORD:',
'titre_breve_proposee' => 'Indsendte nyheder',
'titre_breve_publiee' => 'Offentliggjorte nyheder',
'titre_breve_refusee' => 'Afviste nyheder',
'titre_cadre_raccourcis' => 'GENVEJE:',
'titre_changer_couleur_interface' => '&AElig;ndre farve p&aring; brugergr&aelig;nsefladen',
'titre_forum' => 'Internt forum',
'titre_image_admin_article' => 'Du kan administrere denne artikel',
'titre_image_administrateur' => 'Administrator',
'titre_image_aide' => 'Hj&aelig;lp til dette emne',
'titre_image_auteur_supprime' => 'Forfatter slettet',
'titre_image_redacteur' => 'Forfatter uden adgang',
'titre_image_redacteur_02' => 'Forfatter',
'titre_image_visiteur' => 'Bes&oslash;gende',
'titre_joindre_document' => 'VEDH&AElig;FT DOKUMENT',
'titre_liens_entrants' => 'Dagens indkomne links',
'titre_mots_cles' => 'N&Oslash;GLEORD',
'titre_probleme_technique' => 'Advarsel: et teknisk problem (SQL server) forhindrer adgang til denne del af webstedet.<p>
		Tak for din forst&aring;else.', # MODIF
'titre_publier_document' => 'OFFENTLIGG&Oslash;R ET DOKUMENT I DETTE AFSNIT',
'titre_signatures_attente' => 'Signatures awaiting validation', # NEW
'titre_signatures_confirmees' => 'Confirmed signatures', # NEW
'titre_statistiques' => 'Webstedsstatistik',
'titre_titre_document' => 'Dokumentoverskrift:',
'todo' => 'to come', # NEW
'trad_reference' => '(referenceartikel)',

// Z
'zbug_balise_b_aval' => ': B tag too late in loop', # NEW
'zbug_balise_inexistante' => 'Tag @balise@ wrongly declared for @from@', # NEW
'zbug_balise_sans_argument' => 'Missing argument in the @balise@ tag', # NEW
'zbug_boucle' => 'loop', # NEW
'zbug_boucle_recursive_undef' => 'boucle r&eacute;cursive non d&eacute;finie', # MODIF
'zbug_calcul' => 'calculation', # NEW
'zbug_champ_hors_boucle' => 'Field @champ@ outside loop', # NEW
'zbug_champ_hors_motif' => 'Champ @champ@ hors d\'une boucle de motif @motif@', # MODIF
'zbug_code' => 'code', # NEW
'zbug_critere_inconnu' => 'crit&egrave;re inconnu @critere@', # MODIF
'zbug_distant_interdit' => 'externe interdit', # MODIF
'zbug_doublon_table_sans_cle_primaire' => 'Duplicate entries on a table which does not have a simple primary key', # NEW
'zbug_doublon_table_sans_index' => 'doublons sur une table sans index', # MODIF
'zbug_erreur_boucle_double' => 'BOUCLE@id@: flertydig definition', # MODIF
'zbug_erreur_boucle_fermant' => 'BOUCLE@id@: mangler slutkoden der lukker', # MODIF
'zbug_erreur_boucle_syntaxe' => 'forkert loop (BOUCLE) syntax ', # MODIF
'zbug_erreur_compilation' => 'Compilation error', # NEW
'zbug_erreur_execution_page' => 'erreur d\'ex&eacute;cution de la page', # MODIF
'zbug_erreur_filtre' => 'Fejl - udefineret filter: <b>"@filter@"</b>', # MODIF
'zbug_erreur_meme_parent' => '{meme_parent} ne s\'applique qu\'aux boucles (FORUMS) ou (RUBRIQUES)', # MODIF
'zbug_erreur_squelette' => 'Error(s) in template', # NEW
'zbug_hors_compilation' => 'Uncompiled', # NEW
'zbug_info_erreur_squelette' => 'Fejl p&aring; sitet',
'zbug_inversion_ordre_inexistant' => 'inversion d\'un ordre inexistant', # MODIF
'zbug_pagination_sans_critere' => '#PAGINATION sans crit&egrave;re {pagination} ou employ&eacute; dans une boucle recursive', # MODIF
'zbug_parametres_inclus_incorrects' => 'Param&egrave;tres d\'inclusion incorrects', # MODIF
'zbug_profile' => 'Calculation time: @time@', # NEW
'zbug_resultat' => 'result', # NEW
'zbug_serveur_indefini' => 'serveur SQL ind&eacute;fini', # MODIF
'zbug_statistiques' => 'SQL query statistics in order of duration', # NEW
'zbug_table_inconnue' => 'Unknown SQL table "@table@"', # NEW
'zxml_connus_attributs' => 'known attributes', # NEW
'zxml_de' => 'from', # NEW
'zxml_inconnu_attribut' => 'unknown attribute', # NEW
'zxml_inconnu_balise' => 'unknown tag', # NEW
'zxml_inconnu_entite' => 'unknown entity', # NEW
'zxml_inconnu_id' => 'unknown ID', # NEW
'zxml_mais_de' => 'but from', # NEW
'zxml_non_conforme' => 'not true to the principle', # NEW
'zxml_non_fils' => 'is not a child of', # NEW
'zxml_nonvide_balise' => 'tag not empty', # NEW
'zxml_obligatoire_attribut' => 'required attribute absent in', # NEW
'zxml_succession_fils_incorrecte' => 'incorrect child inheritance', # NEW
'zxml_survoler' => 'to see the correct ones, hover with the cursor', # NEW
'zxml_valeur_attribut' => 'attribute value', # NEW
'zxml_vide_balise' => 'empty tag', # NEW
'zxml_vu' => 'seen before', # NE
);

?>
